AFRL labeling Fiducial Info (sarpy.annotation.afrl_elements.DetailFiducialInfo)
===============================================================================

.. automodule:: sarpy.annotation.afrl_elements.DetailFiducialInfo
    :members:
    :show-inheritance:
    :inherited-members:
